aboutsummaryrefslogtreecommitdiff
path: root/qa
diff options
context:
space:
mode:
authorJeff Garzik <jeff@bloq.com>2015-11-12 15:38:59 -0500
committerJeff Garzik <jeff@bloq.com>2015-11-12 15:38:59 -0500
commit38ed190eefccf8865d984e08f4dfe4063ed8a55b (patch)
treed22bd85c9b62f52271c15f958b0be39b3a27bc09 /qa
parentbd629d77edbeac6ce71a34f6d557c4e00513be44 (diff)
parent971a4e6b86e5bd3ac33441d8c031d63d88c59a8b (diff)
downloadbitcoin-38ed190eefccf8865d984e08f4dfe4063ed8a55b.tar.xz
Merge #6771 from branch 'lowerLimits' of git://github.com/morcos/bitcoin
Diffstat (limited to 'qa')
-rwxr-xr-xqa/rpc-tests/mempool_packages.py19
1 files changed, 11 insertions, 8 deletions
diff --git a/qa/rpc-tests/mempool_packages.py b/qa/rpc-tests/mempool_packages.py
index 6bc6e43f0b..746c26ff5e 100755
--- a/qa/rpc-tests/mempool_packages.py
+++ b/qa/rpc-tests/mempool_packages.py
@@ -11,6 +11,9 @@ from test_framework.util import *
def satoshi_round(amount):
return Decimal(amount).quantize(Decimal('0.00000001'), rounding=ROUND_DOWN)
+MAX_ANCESTORS = 25
+MAX_DESCENDANTS = 25
+
class MempoolPackagesTest(BitcoinTestFramework):
def setup_network(self):
@@ -45,17 +48,17 @@ class MempoolPackagesTest(BitcoinTestFramework):
value = utxo[0]['amount']
fee = Decimal("0.0001")
# 100 transactions off a confirmed tx should be fine
chain = []
- for i in xrange(100):
+ for i in xrange(MAX_ANCESTORS):
(txid, sent_value) = self.chain_transaction(self.nodes[0], txid, 0, value, fee, 1)
value = sent_value
chain.append(txid)
# Check mempool has 100 transactions in it, and descendant
# count and fees should look correct
mempool = self.nodes[0].getrawmempool(True)
- assert_equal(len(mempool), 100)
+ assert_equal(len(mempool), MAX_ANCESTORS)
descendant_count = 1
descendant_fees = 0
descendant_size = 0
@@ -91,18 +94,18 @@ class MempoolPackagesTest(BitcoinTestFramework):
for i in xrange(10):
transaction_package.append({'txid': txid, 'vout': i, 'amount': sent_value})
- for i in xrange(1000):
+ for i in xrange(MAX_DESCENDANTS):
utxo = transaction_package.pop(0)
try:
(txid, sent_value) = self.chain_transaction(self.nodes[0], utxo['txid'], utxo['vout'], utxo['amount'], fee, 10)
for j in xrange(10):
transaction_package.append({'txid': txid, 'vout': j, 'amount': sent_value})
- if i == 998:
+ if i == MAX_DESCENDANTS - 2:
mempool = self.nodes[0].getrawmempool(True)
- assert_equal(mempool[parent_transaction]['descendantcount'], 1000)
+ assert_equal(mempool[parent_transaction]['descendantcount'], MAX_DESCENDANTS)
except JSONRPCException as e:
print e.error['message']
- assert_equal(i, 999)
+ assert_equal(i, MAX_DESCENDANTS - 1)
print "tx that would create too large descendant package successfully rejected"
# TODO: check that node1's mempool is as expected
@@ -45,17 +48,17 @@ class MempoolPackagesTest(BitcoinTestFramework):
value = utxo[0]['amount']
fee = Decimal("0.0001")
- # 100 transactions off a confirmed tx should be fine
+ # MAX_ANCESTORS transactions off a confirmed tx should be fine
chain = []
@@ -45,17 +48,17 @@ class MempoolPackagesTest(BitcoinTestFramework):
value = sent_value
chain.append(txid)
- # Check mempool has 100 transactions in it, and descendant
+ # Check mempool has MAX_ANCESTORS transactions in it, and descendant
# count and fees should look correct
mempool = self.nodes[0].getrawmempool(True)